==> opennms-dao-api-17.0.0-20151007.171205-200-sources.jar: org/opennms/netmgt/dao/api/LldpLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.LldpLink;
import org.opennms.netmgt.model.OnmsNode;


public interface LldpLinkDao extends OnmsDao<LldpLink, Integer> {

    LldpLink get(OnmsNode node, Integer lldpLocalPortNum);

    LldpLink get(Integer nodeId, Integer lldpLocalPortNum);
    
    List<LldpLink> findByNodeId(Integer nodeId);

    List<LldpLink> findLinksForIds(List<Integer> ids);

    void deleteByNodeIdOlderThen(Integer nodeiId, Date now);

}

==> opennms-dao-api-19.0.0-20160920.201952-203-sources.jar: org/opennms/netmgt/dao/api/LldpLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.LldpLink;
import org.opennms.netmgt.model.OnmsNode;


public interface LldpLinkDao extends OnmsDao<LldpLink, Integer> {

    LldpLink get(OnmsNode node, Integer lldpLocalPortNum);

    LldpLink get(Integer nodeId, Integer lldpLocalPortNum);
    
    List<LldpLink> findByNodeId(Integer nodeId);

    List<LldpLink> findLinksForIds(List<Integer> ids);

    void deleteByNodeIdOlderThen(Integer nodeId, Date now);

    void deleteByNodeId(Integer nodeId);

}
